@@ -8,6 +8,7 @@ from celery.worker.request import Request
 from django.conf import settings
 from django.core.exceptions import DisallowedHost
 from django.http.request import split_domain_port
+from django.urls import resolve, NoReverseMatch, Resolver404
 from rest_framework.compat import unicode_http_header
 from rest_framework.utils.mediatypes import _MediaType
 
@@ -43,10 +44,14 @@ def get_client_ip(request):
 
 
 def determine_version(request):
-    media_type = _MediaType((request.META.get("HTTP_ACCEPT") or "").split(",")[0])
-    version = media_type.params.get("version")
-    version = unicode_http_header(version)
-    return version or None
+    if hasattr(request, "version"):
+        if request.version is not None:
+            return str(request.version)
+    elif hasattr(request, "accepted_types"):
+        for t in request.accepted_types:
+            if t.params.get("version") is not None:
+                return unicode_http_header(t.params.get("version"))
+    return None
 
 
 @not_recursive
@@ -86,13 +91,20 @@ class DataDogJSONFormatter(json_log_formatter.JSONFormatter):
             except DisallowedHost:
                 domain, port = None, None
 
+            try:
+                resolver_match = resolve(wsgi_request.path)
+            except (NoReverseMatch, Resolver404):
+                resolver_match = None
+
             log_entry_dict["http.url"] = wsgi_request.get_full_path()
             log_entry_dict["http.url_details.host"] = domain
             log_entry_dict["http.url_details.port"] = int(port) if port else None
             log_entry_dict["http.url_details.path"] = wsgi_request.path_info
             log_entry_dict["http.url_details.queryString"] = wsgi_request.GET.dict()
             log_entry_dict["http.url_details.scheme"] = wsgi_request.scheme
+            log_entry_dict["http.url_details.view_name"] = resolver_match.view_name if resolver_match else None
             log_entry_dict["http.method"] = wsgi_request.method
+            log_entry_dict["http.accept"] = wsgi_request.META.get("HTTP_ACCEPT")
             log_entry_dict["http.referer"] = wsgi_request.META.get("HTTP_REFERER")
             log_entry_dict["http.useragent"] = wsgi_request.META.get("HTTP_USER_AGENT")
             log_entry_dict["http.request_version"] = determine_version(wsgi_request)
